@@ -18,7 +18,7 @@ use Image::ExifTool::XMP;
 use Image::ExifTool::GPS;
 use Image::ExifTool::Protobuf;
 
-$VERSION = '1.13';
+$VERSION = '1.15';
 
 sub ProcessDJIInfo($$$);
 sub ProcessSettings($$$);
@@ -30,6 +30,8 @@ sub ProcessSettings($$$);
     'dvtm_wm265e.proto' => 1,   # Mavic 3
     'dvtm_pm320.proto' => 1,    # Matrice 30
     'dvtm_Mini4_Pro.proto' => 1,    # Matrice 30
+    'dvtm_Mini4_Pro.proto' => 1,    # Matrice 30
+    'dvtm_dji_neo.proto' => 1,  # Neo
 );
 
 my %convFloat2 = (
@@ -138,7 +140,7 @@ my %convFloat2 = (
     GROUPS => { 0 => 'XMP', 1 => 'XMP-drone-dji', 2 => 'Location' },
     NAMESPACE => 'drone-dji',
     TABLE_DESC => 'XMP DJI',
-    VARS => { NO_ID => 1 },
+    VARS => { ID_FMT => 'none' },
     NOTES => 'XMP tags used by DJI for images from drones.',
     AbsoluteAltitude  => { Writable => 'real' },
     RelativeAltitude  => { Writable => 'real' },
@@ -234,13 +236,14 @@ my %convFloat2 = (
         ExifTool currently extracts timed GPS plus a few other tags from DJI devices
         which use the following protocols:  dvtm_AVATA2.proto (Avata 2),
         dvtm_ac203.proto (Osmo Action 4), dvtm_ac204.proto (Osmo Action 5),
-        dvtm_wm265e.proto (Mavic 3), dvtm_pm320.proto (Matrice 30) and
-        dvtm_pm320.proto (Mini 4 Pro).
+        dvtm_wm265e.proto (Mavic 3), dvtm_pm320.proto (Matrice 30),
+        dvtm_Mini4_Pro.proto (Mini 4 Pro) and dvtm_dji_neo.proto (DJI Neo).
 
         Note that with the protobuf format, numerical tags missing from the output
         for a given protocol should be considered to have the default value of 0.
     },
     Protocol => {
+        Notes => "typically protobuf field 1-1-1, but ExifTool doesn't rely on this",
         RawConv => q{
             unless ($Image::ExifTool::DJI::knownProtocol{$val}) {
                 $self->Warn("Unknown protocol $val (please submit sample for testing)");
@@ -266,6 +269,9 @@ my %convFloat2 = (
     },
     'dvtm_ac203_3-2-6-1' => { Name => 'ColorTemperature', Format => 'unsigned' }, # (NC)
    # dvtm_ac203_3-2-9-1 - looks like Z accerometer measurement, but 2 and 3 don't look like other components
+    'dvtm_ac203_3-2-10-2' => { Name => 'AccelerometerX', Format => 'float' } , # (NC) left/right
+    'dvtm_ac203_3-2-10-3' => { Name => 'AccelerometerY', Format => 'float' } , # (NC) front/back
+    'dvtm_ac203_3-2-10-4' => { Name => 'AccelerometerZ', Format => 'float' } , # (NC) up/down
    # dvtm_ac203_3-4-1-4 - model code?
     'dvtm_ac203_3-4-2-1' => {
         Name => 'GPSInfo',
@@ -301,6 +307,9 @@ my %convFloat2 = (
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
     },
     'dvtm_ac204_3-2-6-1' => { Name => 'ColorTemperature', Format => 'unsigned' }, # (NC)
+    'dvtm_ac204_3-2-10-2' => { Name => 'AccelerometerX', Format => 'float' } , # (NC) left/right
+    'dvtm_ac204_3-2-10-3' => { Name => 'AccelerometerY', Format => 'float' } , # (NC) front/back
+    'dvtm_ac204_3-2-10-4' => { Name => 'AccelerometerZ', Format => 'float' } , # (NC) up/down
    # dvtm_ac204_3-4-1-4 - model code?
     'dvtm_ac204_3-4-2-1' => {
         Name => 'GPSInfo',
@@ -413,6 +422,11 @@ my %convFloat2 = (
         Format => 'rational',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
     },
+    'dvtm_pm320_3-2-4-1' => { # (NC)
+        Name => 'FNumber',
+        Format => 'rational',
+        PrintConv => 'Image::ExifTool::Exif::PrintFNumber($val)',
+    },
     'dvtm_pm320_3-2-6-1' => { Name => 'DigitalZoom', Format => 'float' },
     'dvtm_pm320_3-3-4-1' => {
         Name => 'GPSInfo',
@@ -464,12 +478,59 @@ my %convFloat2 = (
         Name => 'GimbalInfo',
         SubDirectory => { TagTable => 'Image::ExifTool::DJI::GimbalInfo' },
     },
+#
+# DJI Neo (very similar to AVATA2)
+#
+   # dvtm_dji_neo_1-1-2 - some version number
+   # dvtm_dji_neo_1-1-3 - some version number
+    'dvtm_dji_neo_1-1-5' => { Name => 'SerialNumber', Notes => 'DJI Neo' }, # (NC)
+    'dvtm_dji_neo_1-1-10' => 'Model',
+   # dvtm_dji_neo_2-2-1-4 - model code?
+   # dvtm_dji_neo_2-2-2-1 - some firmware version?
+   # dvtm_dji_neo_2-2-2-2 - some version number?
+    'dvtm_dji_neo_2-2-3-1' => 'SerialNumber2', # (NC)
+    'dvtm_dji_neo_2-3' => {
+        Name => 'FrameInfo', 
+        SubDirectory => { TagTable => 'Image::ExifTool::DJI::FrameInfo' },
+    },
+   # dvtm_dji_neo_3-1-1 - frame number (starting at 1)
+    'dvtm_dji_neo_3-1-2' => { # (also 3-2-1-6 and 3-4-1-6)
+        Name => 'TimeStamp',
+        Groups => { 2 => 'Time' },
+        Format => 'unsigned',
+        # milliseconds, but I don't know what the zero is
+        ValueConv => '$val / 1e6',
+    },
+   # dvtm_dji_neo_3-2-1-4 - model code?
+   # dvtm_dji_neo_3-2-1-5 - frame rate?
+    'dvtm_dji_neo_3-2-2-1' => { Name => 'ISO', Format => 'float' }, # (NC)
+    'dvtm_dji_neo_3-2-4-1' => {
+        Name => 'ShutterSpeed',
+        Format => 'rational',
+        PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
+    },
+    'dvtm_dji_neo_3-2-6-1' => { Name => 'ColorTemperature', Format => 'unsigned' }, # (NC)
+    'dvtm_dji_neo_3-2-10-1' => { # (NC)
+        Name => 'FNumber',
+        Format => 'rational',
+        PrintConv => 'Image::ExifTool::Exif::PrintFNumber($val)',
+    },
+   # dvtm_dji_neo_3-4-1-4 - model code?
+    'dvtm_dji_neo_3-4-3' => { # (NC)
+        Name => 'DroneInfo',
+        SubDirectory => { TagTable => 'Image::ExifTool::DJI::DroneInfo' },
+    },
+    'dvtm_dji_neo_3-4-4-1' => {
+        Name => 'GPSInfo',
+        SubDirectory => { TagTable => 'Image::ExifTool::DJI::GPSInfo' },
+    },
+    'dvtm_dji_neo_3-4-4-2' => { Name => 'AbsoluteAltitude', Format => 'int64s', ValueConv => '$val / 1000' }, # (NC)
 );
 
 %Image::ExifTool::DJI::DroneInfo = (
     GROUPS => { 0 => 'Protobuf', 1 => 'DJI', 2 => 'Camera' },
     PROCESS_PROC => \&Image::ExifTool::Protobuf::ProcessProtobuf,
-    VARS => { HEX_ID => 0, ID_LABEL => 'Field #' },
+    VARS => { ID_FMT => 'dec', ID_LABEL => 'Field #' },
     1 => { Name => 'DroneRoll',  Format => 'int64s', ValueConv => '$val / 10' },
     2 => { Name => 'DronePitch', Format => 'int64s', ValueConv => '$val / 10' },
     3 => { Name => 'DroneYaw',   Format => 'int64s', ValueConv => '$val / 10' },
@@ -478,7 +539,7 @@ my %convFloat2 = (
 %Image::ExifTool::DJI::GimbalInfo = (
     GROUPS => { 0 => 'Protobuf', 1 => 'DJI', 2 => 'Camera' },
     PROCESS_PROC => \&Image::ExifTool::Protobuf::ProcessProtobuf,
-    VARS => { HEX_ID => 0, ID_LABEL => 'Field #' },
+    VARS => { ID_FMT => 'dec', ID_LABEL => 'Field #' },
     1 => { Name => 'GimbalPitch',Format => 'int64s', ValueConv => '$val / 10' },
     2 => { Name => 'GimbalRoll', Format => 'int64s', ValueConv => '$val / 10' }, # usually 0, so missing
     3 => { Name => 'GimbalYaw',  Format => 'int64s', ValueConv => '$val / 10' },
@@ -487,16 +548,17 @@ my %convFloat2 = (
 %Image::ExifTool::DJI::FrameInfo = (
     GROUPS => { 0 => 'Protobuf', 1 => 'DJI', 2 => 'Video' },
     PROCESS_PROC => \&Image::ExifTool::Protobuf::ProcessProtobuf,
-    VARS => { HEX_ID => 0, ID_LABEL => 'Field #' },
+    VARS => { ID_FMT => 'dec', ID_LABEL => 'Field #' },
     1 => { Name => 'FrameWidth',  Format => 'unsigned' },
     2 => { Name => 'FrameHeight', Format => 'unsigned' },
     3 => { Name => 'FrameRate',   Format => 'float' },
+  # 4-8: seen these values respectively for DJI Neo: 1,8,4,1,4
 );
 
 %Image::ExifTool::DJI::GPSInfo = (
     GROUPS => { 0 => 'Protobuf', 1 => 'DJI', 2 => 'Location' },
     PROCESS_PROC => \&Image::ExifTool::Protobuf::ProcessProtobuf,
-    VARS => { HEX_ID => 0, ID_LABEL => 'Field #' },
+    VARS => { ID_FMT => 'dec', ID_LABEL => 'Field #' },
     1 => {
         Name => 'CoordinateUnits',
         Format  => 'unsigned',
